==> nextcloud-24.0.8.tgz: nextcloud/apps/sharebymail/l10n/is.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "Deilt með %1$s",
    "Shared with {email}" : "Deilt með {email}",
    "Shared with %1$s by %2$s" : "Deilt með %1$s af %2$s",
    "Shared with {email} by {actor}" : "Deilt með {email} af {actor}",
    "Unshared from %1$s" : "Tekið úr deilingu frá %1$s",
    "Unshared from {email}" : "Tekið úr deilingu frá {email}",
    "Unshared from %1$s by %2$s" : "Tekið úr deilingu frá %1$s af %2$s",
    "Unshared from {email} by {actor}" : "Tekið úr deilingu frá {email}} af {actor}",
    "Password for mail share sent to %1$s" : "Lykilorð fyrir póstsameign var sent til %1$s",
    "Password for mail share sent to {email}" : "Lykilorð fyrir póstsameign var sent til {email}",
    "Password for mail share sent to you" : "Lykilorð fyrir póstsameign var sent til þín",
    "You shared %1$s with %2$s by mail" : "Þú deildir %1$s með %2$s með tölvupósti",
    "You shared {file} with {email} by mail" : "Þú deildir {file} með {email} með tölvupósti",
    "%3$s shared %1$s with %2$s by mail" : "%3$s deildi %1$s með %2$s með tölvupósti",
    "{actor} shared {file} with {email} by mail" : "{actor} deildi {file} með {email} með tölvupósti",
    "You unshared %1$s from %2$s by mail" : "Þú tókst %1$s úr deilingu frá %2$s með tölvupósti",
    "You unshared {file} from {email} by mail" : "Þú tókst {file} úr deilingu frá {email} með tölvupósti",
    "%3$s unshared %1$s from %2$s by mail" : "%3$ tók %1$s úr deilingu frá %2$s með tölvupósti",
    "{actor} unshared {file} from {email} by mail" : "{actor} tók {file} úr deilingu frá {email} með tölvupósti",
    "Password to access %1$s was sent to %2s" : "Lykilorð fyrir aðgang að %1$s var sent til %2s",
    "Password to access {file} was sent to {email}" : "Lykilorð fyrir aðgang að {file} var sent til {email}",
    "Password to access %1$s was sent to you" : "Lykilorð fyrir aðgang að %1$s var sent til þín",
    "Password to access {file} was sent to you" : "Lykilorð fyrir aðgang að {file} var sent til þín",
    "Share by mail" : "Deila með tölvupósti",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deiling %1$s mistókst, því þessu atriði er þegar deilt með notandanum %2$s",
    "Failed to send share by email" : "Gat ekki sent sameign með tölvupósti",
    "%1$s shared »%2$s« with you" : "%1$s deildi »%2$s« með þér",
    "%1$s shared »%2$s« with you." : "%1$s deildi »%2$s« með þér.",
    "Click the button below to open it." : "Smelltu á tengilinn hér fyrir neðan til að opna það.",
    "Open »%s«" : "Opna »%s«",
    "%1$s via %2$s" : "%1$s með %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s deildi »%2$s« með þér.\nÞú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s deildi »%2$s« með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.",
    "Password to access »%1$s« shared to you by %2$s" : "Lykilorði fyrir aðgang að »%1$s« var deilt með þér af %2$s",
    "Password to access »%s«" : "Lykilorð fyrir aðgang að »%s«",
    "It is protected with the following password:" : "Það er varið með eftirfarandi lykilorði:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s deildi »%2$s« með þér og vill bæta við:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s deildi »%2$s« með þér og vill bæta við",
    "»%s« added a note to a file shared with you" : "»%s« bætti minnispunkti við skrá sem deilt er með þér",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Þú varst í þessu að deila »%1$s« með %2$s. Sameignin var þegar send til viðtakandans. Vegna öryggisskilmála sem skilgreindir hafa verið af kerfisstjóra %3$s þarf hver sameign að vera varin með lykilorði og að ekki er leyfilegt að senda það lykilorð beint til viðtakandans. Því er nauðsynlegt að þú homir lykilorðinu beint til sjálfs viðtakandans.",
    "Password to access »%1$s« shared by you with %2$s" : "Lykilorði fyrir aðgang að »%1$s« var deilt af þér með %2$s",
    "This is the password:" : "Þetta er lykilorðið:",
    "You can choose a different password at any time in the share dialog." : "Þú getur hvenær sem er valið annað lykilorð með því að fara í deilingargluggann.",
    "Could not find share" : "Gat ekki fundið sameign",
    "Share provider which allows you to share files by mail" : "Deilingarþjónusta sem gerir þér kleift að deila skrám með tölvupósti",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Gerir notendum kleift að deila sérsniðnum tengli á skrá eða möppu með því að setja inn tölvupóstfang.",
    "Send password by mail" : "Senda lykilorð með pósti"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/sharebymail/l10n/is.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Deilt með {email}",
    "Shared with {email} by {actor}" : "Deilt með {email} af {actor}",
    "Unshared from {email}" : "Tekið úr deilingu frá {email}",
    "Unshared from {email} by {actor}" : "Tekið úr deilingu frá {email}} af {actor}",
    "Password for mail share sent to {email}" : "Lykilorð fyrir póstsameign var sent til {email}",
    "Password for mail share sent to you" : "Lykilorð fyrir póstsameign var sent til þín",
    "You shared {file} with {email} by mail" : "Þú deildir {file} með {email} með tölvupósti",
    "{actor} shared {file} with {email} by mail" : "{actor} deildi {file} með {email} með tölvupósti",
    "You unshared {file} from {email} by mail" : "Þú tókst {file} úr deilingu frá {email} með tölvupósti",
    "{actor} unshared {file} from {email} by mail" : "{actor} tók {file} úr deilingu frá {email} með tölvupósti",
    "Password to access {file} was sent to {email}" : "Lykilorð fyrir aðgang að {file} var sent til {email}",
    "Password to access {file} was sent to you" : "Lykilorð fyrir aðgang að {file} var sent til þín",
    "Share by mail" : "Deila með tölvupósti",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deiling %1$s mistókst, því þessu atriði er þegar deilt með notandanum %2$s",
    "Failed to send share by email" : "Gat ekki sent sameign með tölvupósti",
    "%1$s shared »%2$s« with you" : "%1$s deildi »%2$s« með þér",
    "%1$s shared »%2$s« with you." : "%1$s deildi »%2$s« með þér.",
    "Click the button below to open it." : "Smelltu á tengilinn hér fyrir neðan til að opna það.",
    "Open »%s«" : "Opna »%s«",
    "%1$s via %2$s" : "%1$s með %2$s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate mail with a link to access it.\n" : "%1$s deildi »%2$s« með þér.\nÞú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate mail with a link to access it." : "%1$s deildi »%2$s« með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.",
    "Password to access »%1$s« shared to you by %2$s" : "Lykilorði fyrir aðgang að »%1$s« var deilt með þér af %2$s",
    "Password to access »%s«" : "Lykilorð fyrir aðgang að »%s«",
    "It is protected with the following password:" : "Það er varið með eftirfarandi lykilorði:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s deildi »%2$s« með þér og vill bæta við:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s deildi »%2$s« með þér og vill bæta við",
    "»%s« added a note to a file shared with you" : "»%s« bætti minnispunkti við skrá sem deilt er með þér",
    "You just shared »%1$s« with %2$s. The share was already sent to the recipient. Due to the security policies defined by the administrator of %3$s each share needs to be protected by password and it is not allowed to send the password directly to the recipient. Therefore you need to forward the password manually to the recipient." : "Þú varst í þessu að deila »%1$s« með %2$s. Sameignin var þegar send til viðtakandans. Vegna öryggisskilmála sem skilgreindir hafa verið af kerfisstjóra %3$s þarf hver sameign að vera varin með lykilorði og að ekki er leyfilegt að senda það lykilorð beint til viðtakandans. Því er nauðsynlegt að þú homir lykilorðinu beint til sjálfs viðtakandans.",
    "Password to access »%1$s« shared by you with %2$s" : "Lykilorði fyrir aðgang að »%1$s« var deilt af þér með %2$s",
    "This is the password:" : "Þetta er lykilorðið:",
    "You can choose a different password at any time in the share dialog." : "Þú getur hvenær sem er valið annað lykilorð með því að fara í deilingargluggann.",
    "Could not find share" : "Gat ekki fundið sameign",
    "Share provider which allows you to share files by mail" : "Deilingarþjónusta sem gerir þér kleift að deila skrám með tölvupósti",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Gerir notendum kleift að deila sérsniðnum tengli á skrá eða möppu með því að setja inn tölvupóstfang.",
    "Send password by mail" : "Senda lykilorð með pósti",
    "Shared with %1$s" : "Deilt með %1$s",
    "Shared with %1$s by %2$s" : "Deilt með %1$s af %2$s",
    "Unshared from %1$s" : "Tekið úr deilingu frá %1$s",
    "Unshared from %1$s by %2$s" : "Tekið úr deilingu frá %1$s af %2$s",
    "Password for mail share sent to %1$s" : "Lykilorð fyrir póstsameign var sent til %1$s",
    "You shared %1$s with %2$s by mail" : "Þú deildir %1$s með %2$s með tölvupósti",
    "%3$s shared %1$s with %2$s by mail" : "%3$s deildi %1$s með %2$s með tölvupósti",
    "You unshared %1$s from %2$s by mail" : "Þú tókst %1$s úr deilingu frá %2$s með tölvupósti",
    "%3$s unshared %1$s from %2$s by mail" : "%3$ tók %1$s úr deilingu frá %2$s með tölvupósti",
    "Password to access %1$s was sent to %2s" : "Lykilorð fyrir aðgang að %1$s var sent til %2s",
    "Password to access %1$s was sent to you" : "Lykilorð fyrir aðgang að %1$s var sent til þín"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
